summaryrefslogtreecommitdiffstats
path: root/kscd
diff options
context:
space:
mode:
Diffstat (limited to 'kscd')
-rw-r--r--kscd/bwlednum.cpp4
-rw-r--r--kscd/bwlednum.h2
-rw-r--r--kscd/cddbdlg.cpp4
-rw-r--r--kscd/cddbdlg.h2
-rw-r--r--kscd/configWidget.cpp10
-rw-r--r--kscd/configWidget.h2
-rw-r--r--kscd/docking.cpp18
-rw-r--r--kscd/docking.h2
-rw-r--r--kscd/kscd.cpp4
-rw-r--r--kscd/kscd.h2
-rw-r--r--kscd/kscdmagic/xlib.c6
-rw-r--r--kscd/kscdmagic/xlib.h4
-rw-r--r--kscd/ledlamp.cpp2
-rw-r--r--kscd/ledlamp.h2
-rw-r--r--kscd/libwm/audio/audio_sun.c4
-rw-r--r--kscd/libwm/cddaslave.c2
-rw-r--r--kscd/libwm/plat_linux_audio.c4
-rw-r--r--kscd/libwm/plat_sun.c4
-rw-r--r--kscd/libwm/plat_sun_audio.c4
19 files changed, 41 insertions, 41 deletions
diff --git a/kscd/bwlednum.cpp b/kscd/bwlednum.cpp
index 2810135b..385c0c74 100644
--- a/kscd/bwlednum.cpp
+++ b/kscd/bwlednum.cpp
@@ -36,8 +36,8 @@ static char segs[14][8] =
{25, 0, 0, 0, 0, 0, 0, 0} }; // blank
-BW_LED_Number::BW_LED_Number( TQWidget *tqparent, const char *name )
- : TQFrame( tqparent, name ){
+BW_LED_Number::BW_LED_Number( TQWidget *parent, const char *name )
+ : TQFrame( parent, name ){
offcolor = TQColor(100,0,0);
diff --git a/kscd/bwlednum.h b/kscd/bwlednum.h
index 76bc10a8..13064f44 100644
--- a/kscd/bwlednum.h
+++ b/kscd/bwlednum.h
@@ -24,7 +24,7 @@ class BW_LED_Number : public TQFrame
public:
- BW_LED_Number( TQWidget *tqparent=0, const char *name=0 );
+ BW_LED_Number( TQWidget *parent=0, const char *name=0 );
~BW_LED_Number();
void setSmallLED(bool ); // if you LED is small it might look better
diff --git a/kscd/cddbdlg.cpp b/kscd/cddbdlg.cpp
index 13efb8b7..fea5ddd6 100644
--- a/kscd/cddbdlg.cpp
+++ b/kscd/cddbdlg.cpp
@@ -33,8 +33,8 @@ struct mytoc
unsigned absframe;
};
-CDDBDlg::CDDBDlg( TQWidget* tqparent, const char* name )
- : KDialogBase( tqparent, name, false, i18n( "CD Editor" ),
+CDDBDlg::CDDBDlg( TQWidget* parent, const char* name )
+ : KDialogBase( parent, name, false, i18n( "CD Editor" ),
Ok|Cancel|User1|User2, Ok, true )
{
KGlobal::locale()->insertCatalogue("libkcddb");
diff --git a/kscd/cddbdlg.h b/kscd/cddbdlg.h
index cee86052..c07d6655 100644
--- a/kscd/cddbdlg.h
+++ b/kscd/cddbdlg.h
@@ -15,7 +15,7 @@ class CDDBDlg : public KDialogBase
TQ_OBJECT
public:
- CDDBDlg(TQWidget* tqparent, const char* name = 0);
+ CDDBDlg(TQWidget* parent, const char* name = 0);
~CDDBDlg();
void setData(
diff --git a/kscd/configWidget.h b/kscd/configWidget.h
index 5072d930..3a4fa43f 100644
--- a/kscd/configWidget.h
+++ b/kscd/configWidget.h
@@ -34,7 +34,7 @@ class configWidget : public configWidgetUI
TQ_OBJECT
public:
- configWidget(KSCD* player, TQWidget* tqparent = 0, const char* name = 0);
+ configWidget(KSCD* player, TQWidget* parent = 0, const char* name = 0);
~configWidget();
protected:
diff --git a/kscd/docking.cpp b/kscd/docking.cpp
index ca85b914..3759ab7b 100644
--- a/kscd/docking.cpp
+++ b/kscd/docking.cpp
@@ -38,13 +38,13 @@
#include <kdebug.h>
-DockWidget::DockWidget( KSCD* tqparent, const char *name)
- : KSystemTray( tqparent, name )
+DockWidget::DockWidget( KSCD* parent, const char *name)
+ : KSystemTray( parent, name )
{
m_popup = 0;
setPixmap( loadIcon("cdsmall") );
- KActionCollection* actionCollection = tqparent->actionCollection();
+ KActionCollection* actionCollection = parent->actionCollection();
m_backAction = actionCollection->action("Previous");
m_forwardAction = actionCollection->action("Next");
m_backPix = loadIcon("player_start");
@@ -53,11 +53,11 @@ DockWidget::DockWidget( KSCD* tqparent, const char *name)
// popup menu for right mouse button
TQPopupMenu* popup = contextMenu();
- popup->insertItem(KGlobal::iconLoader()->loadIconSet("player_play", KIcon::Small), i18n("Play/Pause"), tqparent, TQT_SLOT(playClicked()));
- popup->insertItem(KGlobal::iconLoader()->loadIconSet("player_stop", KIcon::Small), i18n("Stop"), tqparent, TQT_SLOT(stopClicked()));
- popup->insertItem(KGlobal::iconLoader()->loadIconSet("player_end", KIcon::Small), i18n("Next"), tqparent, TQT_SLOT(nextClicked()));
- popup->insertItem(KGlobal::iconLoader()->loadIconSet("player_start", KIcon::Small), i18n("Previous"), tqparent, TQT_SLOT(prevClicked()));
- popup->insertItem(KGlobal::iconLoader()->loadIconSet("player_eject", KIcon::Small), i18n("Eject"), tqparent, TQT_SLOT(ejectClicked()));
+ popup->insertItem(KGlobal::iconLoader()->loadIconSet("player_play", KIcon::Small), i18n("Play/Pause"), parent, TQT_SLOT(playClicked()));
+ popup->insertItem(KGlobal::iconLoader()->loadIconSet("player_stop", KIcon::Small), i18n("Stop"), parent, TQT_SLOT(stopClicked()));
+ popup->insertItem(KGlobal::iconLoader()->loadIconSet("player_end", KIcon::Small), i18n("Next"), parent, TQT_SLOT(nextClicked()));
+ popup->insertItem(KGlobal::iconLoader()->loadIconSet("player_start", KIcon::Small), i18n("Previous"), parent, TQT_SLOT(prevClicked()));
+ popup->insertItem(KGlobal::iconLoader()->loadIconSet("player_eject", KIcon::Small), i18n("Eject"), parent, TQT_SLOT(ejectClicked()));
TQToolTip::add(this, kapp->aboutData()->programName());
}
@@ -123,7 +123,7 @@ void DockWidget::wheelEvent(TQWheelEvent *e)
if (e->orientation() ==Qt::Horizontal)
return;
- KSCD* kscd = dynamic_cast<KSCD*>(tqparent());
+ KSCD* kscd = dynamic_cast<KSCD*>(parent());
if (kscd == 0)
return;
diff --git a/kscd/docking.h b/kscd/docking.h
index 2ffc431a..56245ffd 100644
--- a/kscd/docking.h
+++ b/kscd/docking.h
@@ -49,7 +49,7 @@ class DockWidget : public KSystemTray
TQ_OBJECT
public:
- DockWidget( KSCD* tqparent, const char *name=0);
+ DockWidget( KSCD* parent, const char *name=0);
~DockWidget();
public slots:
diff --git a/kscd/kscd.cpp b/kscd/kscd.cpp
index 7c8af4b1..604a023d 100644
--- a/kscd/kscd.cpp
+++ b/kscd/kscd.cpp
@@ -89,9 +89,9 @@ bool stoppedByUser = false;
The GUI part
*****************************************************************************/
-KSCD::KSCD( TQWidget *tqparent, const char *name )
+KSCD::KSCD( TQWidget *parent, const char *name )
: DCOPObject("CDPlayer"),
- kscdPanelDlg( tqparent, name, TQt::WDestructiveClose ),
+ kscdPanelDlg( parent, name, TQt::WDestructiveClose ),
configDialog(0L),
cddialog(0L), //!!!!
jumpToTrack(0L),
diff --git a/kscd/kscd.h b/kscd/kscd.h
index c6f2a8c1..a6c192bd 100644
--- a/kscd/kscd.h
+++ b/kscd/kscd.h
@@ -109,7 +109,7 @@ k_dcop:
TQStringList trackList();
public:
- KSCD( TQWidget *tqparent = 0, const char *name = 0 );
+ KSCD( TQWidget *parent = 0, const char *name = 0 );
~KSCD();
virtual bool saveState(TQSessionManager& sm);
diff --git a/kscd/kscdmagic/xlib.c b/kscd/kscdmagic/xlib.c
index 530336cf..b28a0650 100644
--- a/kscd/kscdmagic/xlib.c
+++ b/kscd/kscdmagic/xlib.c
@@ -320,9 +320,9 @@ xdisplay *xalloc_display(const char *s, int xHint, int yHint, int x, int y, xlib
xd->attributes->background_pixel = BlackPixel(xd->display,
xd->screen);
xd->attributes->border_pixel = BlackPixel(xd->display, xd->screen);
- xd->attributes->event_tqmask = ButtonPressMask | StructureNotifyMask | ButtonReleaseMask | ButtonMotionMask | KeyPressMask | ExposureMask | KeyReleaseMask;
+ xd->attributes->event_mask = ButtonPressMask | StructureNotifyMask | ButtonReleaseMask | ButtonMotionMask | KeyPressMask | ExposureMask | KeyReleaseMask;
xd->attributes->override_redirect = False;
- xd->attr_tqmask = CWBackPixel | CWBorderPixel | CWEventMask;
+ xd->attr_mask = CWBackPixel | CWBorderPixel | CWEventMask;
xd->classX = InputOutput;
xd->xcolor.n = 0;
xd->parent_window = RootWindow(xd->display, xd->screen);
@@ -406,7 +406,7 @@ xdisplay *xalloc_display(const char *s, int xHint, int yHint, int x, int y, xlib
xd->window = XCreateWindow(xd->display, xd->parent_window, xHint, yHint,
xd->width, xd->height, xd->border_width,
vis.depth, xd->classX, xd->visual,
- xd->attr_tqmask, xd->attributes);
+ xd->attr_mask, xd->attributes);
if (!xd->fixedcolormap && params->privatecolormap) {
unsigned long pixels[256];
int i;
diff --git a/kscd/kscdmagic/xlib.h b/kscd/kscdmagic/xlib.h
index 00b6242e..73113292 100644
--- a/kscd/kscdmagic/xlib.h
+++ b/kscd/kscdmagic/xlib.h
@@ -66,9 +66,9 @@ typedef struct {
int depth;
unsigned int classX;
Visual *visual;
- unsigned long valuetqmask;
+ unsigned long valuemask;
XSetWindowAttributes *attributes;
- unsigned long attr_tqmask;
+ unsigned long attr_mask;
XSizeHints sizehints;
int screen;
const char *window_name;
diff --git a/kscd/ledlamp.cpp b/kscd/ledlamp.cpp
index 93aa8000..96675921 100644
--- a/kscd/ledlamp.cpp
+++ b/kscd/ledlamp.cpp
@@ -26,7 +26,7 @@
#include "ledlamp.h"
#include "ledlamp.moc"
-LedLamp::LedLamp(TQWidget *tqparent, Type t) : TQFrame(tqparent),
+LedLamp::LedLamp(TQWidget *parent, Type t) : TQFrame(parent),
w( 10 ), h( 7 ), dx( 4 )
{
// Make sure we're in a sane state
diff --git a/kscd/ledlamp.h b/kscd/ledlamp.h
index d7673998..6bd2e44f 100644
--- a/kscd/ledlamp.h
+++ b/kscd/ledlamp.h
@@ -34,7 +34,7 @@ public:
enum Type { Rect, Loop };
- LedLamp(TQWidget *tqparent=0, Type t=Rect);
+ LedLamp(TQWidget *parent=0, Type t=Rect);
enum State { On, Off };
diff --git a/kscd/libwm/audio/audio_sun.c b/kscd/libwm/audio/audio_sun.c
index 93ce78d2..12b7c55c 100644
--- a/kscd/libwm/audio/audio_sun.c
+++ b/kscd/libwm/audio/audio_sun.c
@@ -54,7 +54,7 @@
* a marker into the audio stream; when the audio device driver encounters the
* marker, it increments a field in a status structure. When we see that
* field go up, we grab the next status structure from the queue and send it
- * to the tqparent process.
+ * to the parent process.
*
* The minimum size of the queue depends on the latency of the audio stream.
*/
@@ -284,7 +284,7 @@ sun_audio_send_status( void )
int qhead;
/*
- * Now send the most current status information to our tqparent.
+ * Now send the most current status information to our parent.
*/
if (ioctl(aucfd, AUDIO_GETINFO, &info) < 0)
perror("AUDIO_GETINFO");
diff --git a/kscd/libwm/cddaslave.c b/kscd/libwm/cddaslave.c
index dac475e8..b378f95d 100644
--- a/kscd/libwm/cddaslave.c
+++ b/kscd/libwm/cddaslave.c
@@ -169,7 +169,7 @@ receive_command(struct cdda_device *dev, struct cdda_block* blk)
if (read(0, inbuf, 1) <= 0) {
wmcdda_close(dev);
oops->wmaudio_close();
-/* ERRORLOG("cddaslave: tqparent died, exit\n");*/
+/* ERRORLOG("cddaslave: parent died, exit\n");*/
exit(0);
}
diff --git a/kscd/libwm/plat_linux_audio.c b/kscd/libwm/plat_linux_audio.c
index 690a36e5..9cec45cb 100644
--- a/kscd/libwm/plat_linux_audio.c
+++ b/kscd/libwm/plat_linux_audio.c
@@ -57,7 +57,7 @@ static char plat_linux_audio_id[] = "$Id$";
* a marker into the audio stream; when the audio device driver encounters the
* marker, it increments a field in a status structure. When we see that
* field go up, we grab the next status structure from the queue and send it
- * to the tqparent process.
+ * to the parent process.
*
* The minimum size of the queue depends on the latency of the audio stream.
*/
@@ -275,7 +275,7 @@ wmaudio_send_status( void )
int qhead;
/*
- * Now send the most current status information to our tqparent.
+ * Now send the most current status information to our parent.
*/
if (ioctl(aucfd, AUDIO_GETINFO, &info) < 0)
perror("AUDIO_GETINFO");
diff --git a/kscd/libwm/plat_sun.c b/kscd/libwm/plat_sun.c
index 8d09efee..4e61d68f 100644
--- a/kscd/libwm/plat_sun.c
+++ b/kscd/libwm/plat_sun.c
@@ -111,7 +111,7 @@ sigthawinit( void )
struct sigaction sa;
sa.sa_handler = thawme;
- sigemptyset(&sa.sa_tqmask);
+ sigemptyset(&sa.sa_mask);
sa.sa_flags = 0;
sigaction(SIGTHAW, &sa, NULL);
@@ -400,7 +400,7 @@ gen_get_drive_status( struct wm_drive *d,
* Now install the no-op signal handler.
*/
new_sig.sa_handler = do_nothing;
- memset(&new_sig.sa_tqmask, 0, sizeof(new_sig.sa_tqmask));
+ memset(&new_sig.sa_mask, 0, sizeof(new_sig.sa_mask));
new_sig.sa_flags = 0;
if (sigaction(SIGALRM, &new_sig, &old_sig))
perror("sigaction");
diff --git a/kscd/libwm/plat_sun_audio.c b/kscd/libwm/plat_sun_audio.c
index 3c9dfdc1..34603991 100644
--- a/kscd/libwm/plat_sun_audio.c
+++ b/kscd/libwm/plat_sun_audio.c
@@ -59,7 +59,7 @@ static char plat_sun_audio_id[] = "$Id$";
* a marker into the audio stream; when the audio device driver encounters the
* marker, it increments a field in a status structure. When we see that
* field go up, we grab the next status structure from the queue and send it
- * to the tqparent process.
+ * to the parent process.
*
* The minimum size of the queue depends on the latency of the audio stream.
*/
@@ -279,7 +279,7 @@ wmaudio_send_status( void )
int qhead;
/*
- * Now send the most current status information to our tqparent.
+ * Now send the most current status information to our parent.
*/
if (ioctl(aucfd, AUDIO_GETINFO, &info) < 0)
perror("AUDIO_GETINFO");
diff --git a/kscd/configWidget.cpp b/kscd/configWidget.cpp
index 4d8e03fb..bae787e9 100644
--- a/kscd/configWidget.cpp
+++ b/kscd/configWidget.cpp
@@ -45,8 +45,8 @@ extern "C" {
class SpecialComboBox : public KComboBox
{
public:
- SpecialComboBox(TQWidget* tqparent, const char* name)
- : KComboBox(tqparent, name)
+ SpecialComboBox(TQWidget* parent, const char* name)
+ : KComboBox(parent, name)
{}
// TQComboBox::setCurrentText replaces the current text if
@@ -59,14 +59,14 @@ public:
} ;
/*
* Constructs a configWidget which is a child of 'tqparent', with the
* name 'name' and widget flags set to 'f'.
*
* The dialog will by default be modeless, unless you set 'modal' to
* TRUE to construct a modal dialog.
*/
-configWidget::configWidget(KSCD* player, TQWidget* tqparent, const char* name)
- : configWidgetUI(tqparent, name),
+configWidget::configWidget(KSCD* player, TQWidget* parent, const char* name)
+ : configWidgetUI(parent, name),
mPlayer(player)
{
if (!name)
@@ -59,14 +59,14 @@ public:
} ;
/*
- * Constructs a configWidget which is a child of 'tqparent', with the
+ * Constructs a configWidget which is a child of 'parent', with the
* name 'name' and widget flags set to 'f'.
*